@@ -19,14 +19,16 @@ if not _root_logger.hasHandlers():
     _logger.propagate = False
 
 from lightning_hpo.__about__ import *  # noqa: E402, F401, F403
-from lightning_hpo.optuna_flow import Optimizer  # noqa: E402
-from lightning_hpo.objective import BaseObjective  # noqa: E402
+from lightning_hpo.components.sweep import Sweep  # noqa: E402
+from lightning_hpo.framework.agnostic import Objective  # noqa: E402
+from lightning_hpo.utilities.utils import HPOCloudCompute  # noqa: E402, F401
 
 _PACKAGE_ROOT = os.path.dirname(__file__)
 _PROJECT_ROOT = os.path.dirname(_PACKAGE_ROOT)
 
 from optuna.storages._in_memory import _logger
+
 _logger.disabled = True
 _logger.propagate = False
 
-__all__ = ["BaseObjective", "Optimizer"]
\ No newline at end of file
+__all__ = ["Objective", "Sweep", "HPOCloudCompute"]
