@@ -11,7 +11,9 @@ class StreamLitLogger(Logger):
         super().__init__()
         self.hi_plot = HiPlotFlow()
 
-    def on_after_trial_end(self, sweep_id: str, trial_id: int, monitor: str, score: float, params: Dict[str, Any]):
+    def on_after_experiment_end(
+        self, sweep_id: str, experiment_id: int, monitor: str, score: float, params: Dict[str, Any]
+    ):
         self.hi_plot.data.append({monitor: score, **params})
 
     def connect(self, flow: LightningFlow):
@@ -20,8 +22,8 @@ class StreamLitLogger(Logger):
     def configure_layout(self):
         return [{"name": "Experiment", "content": self.hi_plot}]
 
-    def configure_tracer(self, tracer, sweep_id: str, trial_id: int, params: Dict[str, Any]):
+    def configure_tracer(self, tracer, sweep_id: str, experiment_id: int, experiment_name: str, params: Dict[str, Any]):
         pass
 
-    def get_url(self, trial_id: int) -> None:
+    def get_url(self, experiment_id: int) -> None:
         return None
